@@ -1,6 +1,7 @@
 import document
 import sys
 import requests
+import base64
 import json
 import pickle
 import inspect
@@ -21,6 +22,9 @@ class API(object):
             url = self.base_uri + endpoint + "?" + urllib.urlencode(params)
             req = urllib2.Request(url)
             req.add_header('Content-Type', 'application/json')
+            auth = '%s:%s' % (params['username'], params['apikey'])
+            base64string = base64.encodestring(auth).replace('\n', '')
+            req.add_header("Authorization", "Basic %s" % base64string)
             response = urllib2.urlopen(req)
             rsp = response.read()
             return json.loads(rsp)
@@ -32,6 +36,9 @@ class API(object):
             url = self.base_uri + endpoint + "?" + urllib.urlencode(params)
             req = urllib2.Request(url)
             req.add_header('Content-Type', 'application/json')
+            auth = '%s:%s' % (params['username'], params['apikey'])
+            base64string = base64.encodestring(auth).replace('\n', '')
+            req.add_header("Authorization", "Basic %s" % base64string)
             response = urllib2.urlopen(req, json.dumps(data))
             rsp = response.read()
             return json.loads(rsp)
